@@ -20,3 +20,8 @@ SELECT * FROM pgr_astar(
     'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
     ARRAY[7, 2], ARRAY[3, 12], heuristic := 2);
 \echo --q6
+SELECT * FROM pgr_astar(
+    'SELECT id, source, target, cost, reverse_cost, x1, y1, x2, y2 FROM edge_table',
+    'SELECT * FROM ( VALUES (7, 3), (2, 12) ) AS t(source, target)',
+    heuristic := 2);
+\echo --q7
