@@ -24,3 +24,7 @@ SELECT * FROM pgr_bdDijkstra(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2, 7], ARRAY[3, 11]);
 \echo -- q6
+SELECT * FROM pgr_bdDijkstra(
+    'SELECT id, source, target, cost, reverse_cost FROM edge_table',
+    'SELECT * FROM ( VALUES (2, 3), (7, 11) ) AS t(source, target)');
+\echo -- q7
