@@ -22,4 +22,8 @@ SELECT * FROM pgr_dagShortestPath(
     ARRAY[1, 4],ARRAY[12,6]
 );
 \echo -- q5
-
+SELECT * FROM pgr_dagShortestPath(
+    'SELECT id, source, target, cost FROM edge_table',
+    'SELECT * FROM ( VALUES (1, 6), (4, 12) ) AS t(source, target)'
+);
+\echo -- q6
