@@ -22,10 +22,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_BELLMAN_FORD_PGR_EDWARDMOORE_HPP_
 #pragma once
 
-#include<limits>
-#include<algorithm>
-#include<vector>
+#include <limits>
+#include <algorithm>
+#include <vector>
 #include <deque>
+#include <map>
 
 
 #include "cpp_common/basePath_SSEC.hpp"
@@ -75,6 +76,48 @@ class Pgr_edwardMoore {
         return paths;
     }
 
+    // preparation for the parallel arrays
+    std::deque<Path> edwardMoore(
+        G &graph,
+        const std::vector<pgr_combination_t> &combinations) {
+        std::deque<Path> paths;
+
+        // group targets per distinct source
+        std::map< int64_t, std::vector<int64_t> > vertex_map;
+        for (const pgr_combination_t &comb : combinations) {
+            std::map< int64_t, std::vector<int64_t> >::iterator it = vertex_map.find(comb.source);
+            if (it != vertex_map.end()) {
+                it->second.push_back(comb.target);
+            } else {
+                std::vector<int64_t > targets{comb.target};
+                vertex_map[comb.source] = targets;
+            }
+        }
+
+        for (const auto &start_ends : vertex_map) {
+            std::deque<Path> result_paths = one_to_many_edwardMoore(
+                graph,
+                start_ends.first,
+                start_ends.second);
+
+            paths.insert(
+                paths.end(),
+                std::make_move_iterator(result_paths.begin()),
+                std::make_move_iterator(result_paths.end()));
+        }
+
+        std::sort(paths.begin(), paths.end(),
+                  [](const Path &e1, const Path &e2) -> bool {
+                      return e1.end_id() < e2.end_id();
+                  });
+        std::stable_sort(paths.begin(), paths.end(),
+                         [](const Path &e1, const Path &e2) -> bool {
+                             return e1.start_id() < e2.start_id();
+                         });
+
+        return paths;
+    }
+
  private:
     E DEFAULT_EDGE;
 
