@@ -24,14 +24,22 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifndef INCLUDE_DRIVERS_WITHPOINTS_WITHPOINTS_DRIVER_H_
 #define INCLUDE_DRIVERS_WITHPOINTS_WITHPOINTS_DRIVER_H_
 #pragma once
 
+/* for size-t */
+#ifdef __cplusplus
+#   include <cstddef>
+#else
+#   include <stddef.h>
+#endif
+
 #include "c_types/point_on_edge_t.h"
 #include "c_types/pgr_edge_t.h"
+#include "c_types/pgr_combination_t.h"
 #include "c_types/general_path_element_t.h"
 
 #ifdef __cplusplus
@@ -54,6 +62,9 @@ extern "C" {
             pgr_edge_t *edges_of_points,
             size_t total_edges_of_points,
 
+            pgr_combination_t  *combinations,
+            size_t total_combinations,
+
             int64_t *start_pidsArr,
             size_t size_start_pidsArr,
 
