@@ -28,6 +28,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_MAX_FLOW_PGR_MINCOSTMAXFLOW_HPP_
 #pragma once
 
+#include <boost/graph/successive_shortest_path_nonnegative_weights.hpp>
+#include <boost/graph/find_flow_cost.hpp>
+
 #include <map>
 #include <string>
 #include <utility>
@@ -35,20 +38,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <set>
 #include <limits>
 
-#include "max_flow/pgr_costFlowGraph.hpp"
-
-#if Boost_VERSION_MACRO >= 105500
-#include <boost/graph/successive_shortest_path_nonnegative_weights.hpp>
-#include <boost/graph/find_flow_cost.hpp>
-#else
-#include "boost/successive_shortest_path_nonnegative_weights.hpp"
-#include "boost/find_flow_cost.hpp"
-#endif
-
-
-
 #include "c_types/pgr_flow_t.h"
 #include "c_types/pgr_costFlow_t.h"
+#include "max_flow/pgr_costFlowGraph.hpp"
 
 namespace pgrouting {
 namespace graph {
