@@ -35,17 +35,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <memory>
 #include <utility>
 
-#include "c_types/pickDeliver/pickDeliveryOrders_t.h"
-#include "c_types/pickDeliver/vehicle_t.h"
 #include "c_types/pickDeliver/general_vehicle_orders_t.h"
+#include "c_types/pickDeliver/vehicle_t.h"
+#include "c_types/pickDeliver/pickDeliveryOrders_t.h"
 #include "vrp/pd_problem.h"
 #include "cpp_common/Dmatrix.h"
-#include "vrp/pd_orders.h"
 #include "vrp/fleet.h"
+#include "vrp/pd_orders.h"
 #include "vrp/solution.h"
-#if 0
-#include "cpp_common/identifiers.hpp"
-#endif
 
 namespace pgrouting {
 namespace vrp {
@@ -65,15 +62,6 @@ class Pgr_pickDeliver : public PD_problem {
     friend Initial_solution;
 
  public:
-#if 0
-    Pgr_pickDeliver(
-            const std::vector<PickDeliveryOrders_t> &pd_orders,
-            const std::vector<Vehicle_t> &vehicles,
-            double factor,
-            size_t max_cycles,
-            int initial);
-#endif
-
     Pgr_pickDeliver(
             const std::vector<PickDeliveryOrders_t> &pd_orders,
             const std::vector<Vehicle_t> &vehicles,
@@ -88,29 +76,22 @@ class Pgr_pickDeliver : public PD_problem {
         get_postgres_result() const;
 
 
-    Solution optimize(const Solution init_solution);
     size_t max_cycles() const {return m_max_cycles;}
 
-#if 0
-    inline size_t& node_id() {return m_node_id;}
-#endif
-
     void add_node(const Vehicle_node &node);
 
-#if 0
-    void add_base_node(std::unique_ptr<Base_node> node_ptr) {
-        m_base_nodes.push_back(std::move(node_ptr));
-    }
-#endif
-
     Initials_code get_kind() const {
         return (Initials_code) m_initial_id;
     }
 
-#if 1
-    // TODO(vicky) delete this function
-    bool nodesOK() const;
-#endif
+    std::vector<Vehicle_node> get_nodes() const {
+        return m_nodes;
+    }
+
+    pgrouting::tsp::Dmatrix get_cost_matrix() const {
+        return m_cost_matrix;
+    }
+
     Fleet trucks() const {return m_trucks;}
 
     /** message controller for all classes */
@@ -125,21 +106,9 @@ class Pgr_pickDeliver : public PD_problem {
     //! maximum cycles in the optimization
     size_t m_max_cycles;
 
-#if 0
-    //! used to keep track of the next id the node gets in the eucledian version
-    size_t m_node_id;
-#endif
-
-
- public:
-    // TODO(vicky) make this private
     std::vector<Vehicle_node> m_nodes;
-#if 0
-    std::vector<std::unique_ptr<Base_node>> m_base_nodes;
-#endif
     pgrouting::tsp::Dmatrix m_cost_matrix;
 
- private:
     PD_Orders m_orders;
     Fleet m_trucks;
     std::vector<Solution> solutions;
