@@ -12,6 +12,12 @@ DECLARE
 sql_Combinations TEXT;
 sql_Many TEXT;
 BEGIN
+  IF NOT min_version('3.1.0') THEN
+    RETURN QUERY
+    SELECT skip(1, 'Combinations signature added on 3.1.0');
+    RETURN;
+  END IF;
+
 
     sql_Combinations := '';
     sql_Many := '';
