@@ -1,7 +1,7 @@
 \i setup.sql
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
-SELECT plan(224);
+SELECT plan(226);
 
 
 SELECT has_function('pgr_boykovkolmogorov',
@@ -26,6 +26,16 @@ SELECT function_returns('pgr_boykovkolmogorov',
     ARRAY['text', 'anyarray', 'anyarray'],
     'setof record');
 
+-- new signature on 3.2
+SELECT CASE
+WHEN NOT min_version('3.2.0') THEN
+  skip(2, 'Combinations functiontionality new on 3.2.0')
+ELSE
+  collect_tap(
+    has_function('pgr_boykovkolmogorov', ARRAY['text', 'text']),
+    function_returns('pgr_boykovkolmogorov', ARRAY['text', 'text'], 'setof record')
+  )
+END;
 
 -- ONLY WORKS ON DIRECTED GRAPH
 SELECT style_max_flow('pgr_boykovkolmogorov', ', 2, 3)');
