@@ -1,20 +1,7 @@
 \i setup.sql
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
-SELECT plan(67);
-
-PREPARE edges AS
-SELECT id, source, target, cost, reverse_cost  FROM edge_table;
-
-PREPARE null_ret AS
-SELECT id FROM edge_table_vertices_pgr  WHERE id IN (-1);
-
-PREPARE null_ret_arr AS
-SELECT array_agg(id) FROM edge_table_vertices_pgr  WHERE id IN (-1);
-
-SELECT isnt_empty('edges', 'Should be not empty to tests be meaningful');
-SELECT is_empty('null_ret', 'Should be empty to tests be meaningful');
-SELECT set_eq('null_ret_arr', 'SELECT NULL::BIGINT[]', 'Should be empty to tests be meaningful');
+SELECT CASE WHEN NOT min_version('3.2.0') THEN plan(68) ELSE plan(81) END;
 
 
 CREATE OR REPLACE FUNCTION test_function()
@@ -24,6 +11,23 @@ DECLARE
 params TEXT[];
 subs TEXT[];
 BEGIN
+  PREPARE edges AS
+  SELECT id, source, target, cost, reverse_cost  FROM edge_table;
+
+  PREPARE null_ret AS
+  SELECT id FROM edge_table_vertices_pgr  WHERE id IN (-1);
+
+  PREPARE null_ret_arr AS
+  SELECT array_agg(id) FROM edge_table_vertices_pgr  WHERE id IN (-1);
+
+
+  RETURN QUERY
+  SELECT isnt_empty('edges', 'Should be not empty to tests be meaningful');
+  RETURN QUERY
+  SELECT is_empty('null_ret', 'Should be empty to tests be meaningful');
+  RETURN QUERY
+  SELECT set_eq('null_ret_arr', 'SELECT NULL::BIGINT[]', 'Should be empty to tests be meaningful');
+
     -- one to one
     params = ARRAY[
     '$$edges$$'
@@ -98,11 +102,41 @@ BEGIN
     ]::TEXT[];
     RETURN query SELECT * FROM no_crash_test('pgr_edgeDisjointPaths', params, subs);
 
+    -- Combinations SQL
+    IF NOT min_version('3.2.0') THEN
+      RETURN QUERY
+      SELECT skip(1, 'Combinations functionality is new on 3.2.0');
+      RETURN;
+    END IF;
+
+    PREPARE combinations AS
+    SELECT source, target  FROM combinations_table WHERE target > 2;
+    PREPARE null_combinations AS
+    SELECT source, target FROM combinations_table WHERE source IN (-1);
+    RETURN QUERY
+    SELECT isnt_empty('combinations', 'Should be not empty to tests be meaningful');
+    RETURN QUERY
+    SELECT is_empty('null_combinations', 'Should be empty to tests be meaningful');
+    params = ARRAY['$$edges$$', '$$combinations$$']::TEXT[];
+    subs = ARRAY[
+    'NULL',
+    '$$(SELECT source, target FROM combinations_table  WHERE source IN (-1))$$'
+    ]::TEXT[];
+
+    RETURN query SELECT * FROM no_crash_test('pgr_edgeDisjointPaths', params, subs);
+
+    subs = ARRAY[
+    'NULL',
+    'NULL::TEXT'
+    ]::TEXT[];
+    RETURN query SELECT * FROM no_crash_test('pgr_edgeDisjointPaths', params, subs);
+
 END
 $BODY$
 LANGUAGE plpgsql VOLATILE;
 
 
 SELECT * FROM test_function();
+SELECT finish();
 
 ROLLBACK;
