@@ -1,11 +1,8 @@
-
-
-
 \i setup.sql
 SET client_min_messages TO WARNING;
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
-SELECT plan(4);
+SELECT plan(3);
 
 
 SELECT pgr_analyzegraph('edge_table', 0.000001);
@@ -21,19 +18,6 @@ PREPARE vals AS
 VALUES (1, 7), (2,3), (3,5), (4,2);
 SELECT set_eq('q1', 'vals', '3: (N,M) M vertices referenced by N edges') ;
 
-SELECT * FROM edge_table_vertices_pgr order by id;
-
-SELECT * FROM TODO_START();
-
-PREPARE q3 AS
-SELECT pgr_analyzegraph('edge_table', 0.000001);
-
-PREPARE stats AS
-VALUES (2,7,1,1,0);
-
-SELECT set_eq('q3','stats', '4: pgr_createVerticesTable: Instead of returning OK, return the expected statistics');
-
-SELECT * FROM TODO_END();
 
 SELECT finish();
 ROLLBACK;
