@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  * this file is not compiled with boost 1.53 or less
  */
 #include "drivers/alpha_shape/alphaShape_driver.h"
+#include <boost/geometry/io/wkt/write.hpp>
 
 #include <cmath>
 #include <vector>
@@ -41,11 +42,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "cpp_common/pgr_base_graph.hpp"
 #include "cpp_common/bpoint.hpp"
 #include "cpp_common/bline.hpp"
-#if Boost_VERSION_MACRO >= 105600
-#include <boost/geometry/io/wkt/write.hpp>
-#else
-#include <boost/bgeometry/io/wkt/write.hpp>
-#endif
 
 
 namespace {
