@@ -28,32 +28,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "alphaShape/pgr_alphaShape.h"
 
 #include <visitors/dijkstra_one_goal_visitor.hpp>
-#if Boost_VERSION_MACRO >= 105500
 #include <boost/graph/dijkstra_shortest_paths.hpp>
-#else
-#include "boost/dijkstra_shortest_paths.hpp"
-#endif
 #include <boost/graph/filtered_graph.hpp>
 
-#if Boost_VERSION_MACRO >= 105600
 #include <boost/geometry/algorithms/num_points.hpp>
 #include <boost/geometry/algorithms/append.hpp>
 #include <boost/geometry/algorithms/area.hpp>
-#  if Boost_VERSION_MACRO >= 107500
+#if Boost_VERSION_MACRO >= 107500
 #    include <boost/geometry/strategies/strategies.hpp>
-#  else
+#else
 #    include <boost/geometry/strategies/agnostic/point_in_point.hpp>
-#  endif
+#endif
 #include <boost/geometry/algorithms/correct.hpp>
 #include <boost/geometry/algorithms/distance.hpp>
-#else
-#include <boost/bgeometry/algorithms/num_points.hpp>
-#include <boost/bgeometry/algorithms/append.hpp>
-#include <boost/bgeometry/algorithms/area.hpp>
-#include <boost/bgeometry/strategies/agnostic/point_in_point.hpp>
-#include <boost/bgeometry/algorithms/correct.hpp>
-#include <boost/bgeometry/algorithms/distance.hpp>
-#endif
 
 
 #include <sstream>
