@@ -35,6 +35,26 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "c_common/get_check_data.h"
 #include "c_common/time_msg.h"
 
+/*
+
+.. Matrix SQL definition start
+
+Matrix SQL
+.................................................................................
+
+**Matrix SQL**: an SQL query, which should return a set of rows with the following columns:
+
+============= ================= =================================================
+Column        Type              Description
+============= ================= =================================================
+**start_vid** ``ANY-INTEGER``   Identifier of the starting vertex.
+**end_vid**   ``ANY-INTEGER``   Identifier of the ending vertex.
+**agg_cost**  ``ANY-NUMERICAL`` Cost for going from start_vid to end_vid
+============= ================= =================================================
+
+.. Matrix SQL definition end
+
+*/
 
 
 static
