@@ -172,14 +172,6 @@ Solution::tau(const std::string &title) const {
     return log.str();
 }
 
-void
-Solution::sort_by_id() {
-    std::sort(fleet.begin(), fleet.end(), []
-            (const Vehicle_pickDeliver &lhs, const Vehicle_pickDeliver &rhs)
-            -> bool {
-            return lhs.idx() < rhs.idx();
-            });
-}
 
 std::ostream&
 operator << (std::ostream &log, const Solution &solution) {
