@@ -21,7 +21,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-********************************************************************PGR-GNU*/
+ ********************************************************************PGR-GNU*/
 
 #ifdef __MINGW32__
 #include <winsock2.h>
@@ -29,6 +29,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #endif
 
 
+#include <utility>
+#include <queue>
+#include <vector>
 #include <functional>
 #include "trsp/GraphDefinition.h"
 
@@ -62,7 +65,7 @@ void GraphDefinition::init() {
 // -------------------------------------------------------------------------
 void GraphDefinition::deleteall() {
     std::vector<GraphEdgeInfo*>::iterator it;
-    for (it = m_vecEdgeVector.begin(); it != m_vecEdgeVector.end(); it++) {
+    for (it = m_vecEdgeVector.begin(); it != m_vecEdgeVector.end(); ++it) {
         delete *it;
     }
     m_vecEdgeVector.clear();
@@ -73,10 +76,10 @@ void GraphDefinition::deleteall() {
 
 
 // -------------------------------------------------------------------------
-double GraphDefinition::construct_path(long ed_id, long v_pos) {
+double GraphDefinition::construct_path(int64 ed_id, int64 v_pos) {
     if (parent[ed_id].ed_ind[v_pos] == -1) {
         path_element_tt pelement;
-        GraphEdgeInfo* cur_edge = m_vecEdgeVector[ed_id];
+        GraphEdgeInfo* cur_edge = m_vecEdgeVector[static_cast<size_t>(ed_id)];
         if (v_pos == 0) {
             pelement.vertex_id = cur_edge->m_lStartNode;
             pelement.cost = cur_edge->m_dCost;
@@ -92,7 +95,7 @@ double GraphDefinition::construct_path(long ed_id, long v_pos) {
     double ret = construct_path(parent[ed_id].ed_ind[v_pos],
         parent[ed_id].v_pos[v_pos]);
     path_element_tt pelement;
-    GraphEdgeInfo* cur_edge = m_vecEdgeVector[ed_id];
+    GraphEdgeInfo* cur_edge = m_vecEdgeVector[static_cast<size_t>(ed_id)];
     if (v_pos == 0) {
         pelement.vertex_id = cur_edge->m_lStartNode;
         pelement.cost = m_dCost[ed_id].endCost - ret;  // cur_edge.m_dCost;
@@ -112,30 +115,30 @@ double GraphDefinition::construct_path(long ed_id, long v_pos) {
 
 // -------------------------------------------------------------------------
 double GraphDefinition::getRestrictionCost(
-    long edge_ind,
+    int64 edge_ind,
     GraphEdgeInfo& new_edge,
     bool isStart) {
     double cost = 0.0;
-    long edge_id = new_edge.m_lEdgeID;
+    int64 edge_id = new_edge.m_lEdgeID;
     if (m_ruleTable.find(edge_id) == m_ruleTable.end()) {
         return(0.0);
     }
     std::vector<Rule> vecRules = m_ruleTable[edge_id];
-    long st_edge_ind = edge_ind;
+    int64 st_edge_ind = edge_ind;
     for (const auto &rule : vecRules) {
         bool flag = true;
-        long v_pos = (isStart?0:1);
+        int64 v_pos = (isStart?0:1);
         edge_ind = st_edge_ind;
         for (auto const &precedence : rule.precedencelist) {
             if (edge_ind == -1) {
                 flag = false;
                 break;
             }
-            if (precedence != m_vecEdgeVector[edge_ind]->m_lEdgeID) {
+            if (precedence != m_vecEdgeVector[static_cast<size_t>(edge_ind)]->m_lEdgeID) {
                 flag = false;
                 break;
             }
-            auto parent_ind = parent[edge_ind].ed_ind[v_pos];
+            auto parent_ind = parent[static_cast<size_t>(edge_ind)].ed_ind[static_cast<size_t>(v_pos)];
             v_pos = parent[edge_ind].v_pos[v_pos];
             edge_ind = parent_ind;
         }
@@ -148,18 +151,16 @@ double GraphDefinition::getRestrictionCost(
 
 // -------------------------------------------------------------------------
 void GraphDefinition::explore(
-    long cur_node,
+    int64 cur_node,
     GraphEdgeInfo& cur_edge,
     bool isStart,
     LongVector &vecIndex,
     std::priority_queue<PDP, std::vector<PDP>,
     std::greater<PDP> > &que) {
-    double extCost = 0.0;
-    GraphEdgeInfo* new_edge;
     double totalCost;
     for (const auto &index : vecIndex) {
-        new_edge = m_vecEdgeVector[index];
-        extCost = 0.0;
+        auto new_edge = m_vecEdgeVector[static_cast<size_t>(index)];
+        double extCost = 0.0;
         if (m_bIsturnRestrictOn) {
             extCost = getRestrictionCost(cur_edge.m_lEdgeIndex,
                  *new_edge, isStart);
@@ -203,179 +204,28 @@ void GraphDefinition::explore(
 }
 
 
-// -------------------------------------------------------------------------
-int GraphDefinition::multi_dijkstra(
-    edge_t *edges,
-    size_t edge_count,
-    std::vector<int> vertices,
-    bool directed,
-    bool has_reverse_cost,
-    path_element_tt **path,
-    size_t *path_count,
-    char **err_msg,
-    std::vector<PDVI> &ruleList) {
-    construct_graph(edges, edge_count, has_reverse_cost, directed);
-    if (ruleList.size() > 0) {
-        m_ruleTable.clear();
-        LongVector vecsource;
-        for (const auto &rule : ruleList) {
-            std::vector<long> temp_precedencelist;
-            temp_precedencelist.clear();
-            for (auto const &seq : rule.second) {
-                temp_precedencelist.push_back(seq);
-            }
-            long dest_edge_id = rule.second[0];
-            if (m_ruleTable.find(dest_edge_id) != m_ruleTable.end()) {
-                m_ruleTable[dest_edge_id].push_back(Rule(rule.first,
-                    temp_precedencelist));
-            } else {
-                std::vector<Rule> temprules;
-                temprules.clear();
-                temprules.push_back(Rule(rule.first, temp_precedencelist));
-                m_ruleTable.insert(std::make_pair(dest_edge_id, temprules));
-            }
-        }
-        m_bIsturnRestrictOn = true;
-    }
-    parent = new PARENT_PATH[edge_count + 1];
-    m_dCost = new CostHolder[edge_count + 1];
-    m_vecPath.clear();
-    size_t i;
-    size_t total_vertices = vertices.size();
-    for (i = 0; i < total_vertices - 1; i++) {
-        int ret = my_dijkstra(vertices[i], vertices[i + 1], edge_count,
-                err_msg);
-        if (ret < 0) {
-            deleteall();
-            return -1;
-        }
-    }
-
-    *path = (path_element_tt *) malloc(sizeof(path_element_tt) *
-    (m_vecPath.size() + 1));
-    *path_count = static_cast<int>(m_vecPath.size());
-
-    for (size_t  i = 0; i < *path_count; i++) {
-        (*path)[i].vertex_id = m_vecPath[i].vertex_id;
-        (*path)[i].edge_id = m_vecPath[i].edge_id;
-        (*path)[i].cost = m_vecPath[i].cost;
-    }
-    deleteall();
-    return 0;
-}
 
 
 // -------------------------------------------------------------------------
-int GraphDefinition::my_dijkstra(long start_vertex, long end_vertex,
-    size_t edge_count, char **err_msg) {
-    if (!m_bIsGraphConstructed) {
-        *err_msg = (char *)"Graph not Ready!";
-        return -1;
-    }
-    unsigned int i;
-    for (i = 0; i <= edge_count; i++) {
-        m_dCost[i].startCost = 1e15;
-        m_dCost[i].endCost = 1e15;
-    }
+int GraphDefinition::my_dijkstra1(
+        edge_t *edges, size_t edge_count,
+        int64 start_edge_id, double start_part,
+        int64 end_edge_id, double end_part,
+        bool directed, bool has_reverse_cost,
 
-    if (m_mapNodeId2Edge.find(start_vertex) == m_mapNodeId2Edge.end()) {
-        *err_msg = (char *)"Source Not Found";
-        deleteall();
-        return -1;
-    }
-
-    if (m_mapNodeId2Edge.find(end_vertex) == m_mapNodeId2Edge.end()) {
-        *err_msg = (char *)"Destination Not Found";
-        deleteall();
-        return -1;
-    }
-
-    std::priority_queue<PDP, std::vector<PDP>, std::greater<PDP> > que;
-    LongVector vecsource = m_mapNodeId2Edge[start_vertex];
-    GraphEdgeInfo* cur_edge = NULL;
-
-    for (const auto &source : vecsource) {
-        cur_edge = m_vecEdgeVector[source];
-        if (cur_edge->m_lStartNode == start_vertex) {
-            if (cur_edge->m_dCost >= 0.0) {
-                m_dCost[cur_edge->m_lEdgeIndex].endCost = cur_edge->m_dCost;
-                parent[cur_edge->m_lEdgeIndex].v_pos[0] = -1;
-                parent[cur_edge->m_lEdgeIndex].ed_ind[0] = -1;
-                que.push(std::make_pair(cur_edge->m_dCost,
-                    std::make_pair(cur_edge->m_lEdgeIndex, true)));
-                }
-            } else {
-                if (cur_edge->m_dReverseCost >= 0.0) {
-                    m_dCost[cur_edge->m_lEdgeIndex].startCost =
-                    cur_edge->m_dReverseCost;
-                    parent[cur_edge->m_lEdgeIndex].v_pos[1] = -1;
-                    parent[cur_edge->m_lEdgeIndex].ed_ind[1] = -1;
-                    que.push(std::make_pair(cur_edge->m_dReverseCost,
-                        std::make_pair(cur_edge->m_lEdgeIndex, false)));
-                    }
-            }
-        }
-
-        long cur_node = -1;
-
-        while (!que.empty()) {
-            PDP cur_pos = que.top();
-            que.pop();
-            long cured_index = cur_pos.second.first;
-            cur_edge = m_vecEdgeVector[cured_index];
-
-            if (cur_pos.second.second) {  // explore edges connected to end node
-                cur_node = cur_edge->m_lEndNode;
-                if (cur_edge->m_dCost < 0.0)
-                    continue;
-                if (cur_node == end_vertex)
-                    break;
-                explore(cur_node, *cur_edge, true,
-                    cur_edge->m_vecEndConnedtedEdge, que);
-            } else {  // explore edges connected to start node
-                cur_node = cur_edge->m_lStartNode;
-                if (cur_edge->m_dReverseCost < 0.0)
-                    continue;
-                if (cur_node == end_vertex)
-                    break;
-                explore(cur_node, *cur_edge, false,
-                    cur_edge->m_vecStartConnectedEdge, que);
-            }
-        }
-        if (cur_node != end_vertex) {
-            *err_msg = (char *)"Path Not Found";
-            deleteall();
-            return -1;
-        } else {
-            if (cur_node == cur_edge->m_lStartNode) {
-                construct_path(cur_edge->m_lEdgeIndex, 1);
-            } else {
-                construct_path(cur_edge->m_lEdgeIndex, 0);
-            }
-            path_element_tt pelement;
-            pelement.vertex_id = end_vertex;
-            pelement.edge_id = -1;
-            pelement.cost = 0.0;
-            m_vecPath.push_back(pelement);
-        }
-    return 0;
-}
-
-
-// -------------------------------------------------------------------------
-int GraphDefinition::my_dijkstra(edge_t *edges, size_t edge_count,
-    long start_edge_id, double start_part, long end_edge_id, double end_part,
-    bool directed, bool has_reverse_cost, path_element_tt **path,
-    size_t *path_count, char **err_msg, std::vector<PDVI> &ruleList) {
+        path_element_tt **path,
+        size_t *path_count,
+        char **err_msg,
+        std::vector<PDVI> &ruleList) {
     if (!m_bIsGraphConstructed) {
             init();
             construct_graph(edges, edge_count, has_reverse_cost, directed);
             m_bIsGraphConstructed = true;
         }
         GraphEdgeInfo* start_edge_info =
-        m_vecEdgeVector[m_mapEdgeId2Index[start_edge_id]];
+        m_vecEdgeVector[static_cast<size_t>(m_mapEdgeId2Index[static_cast<int64>(start_edge_id)])];
         edge_t start_edge;
-        long start_vertex, end_vertex;
+        int64 start_vertex, end_vertex;
         m_dStartpart = start_part;
         m_dEndPart = end_part;
         m_lStartEdgeId = start_edge_id;
@@ -411,7 +261,7 @@ int GraphDefinition::my_dijkstra(edge_t *edges, size_t edge_count,
         }
 
     GraphEdgeInfo* end_edge_info =
-    m_vecEdgeVector[m_mapEdgeId2Index[end_edge_id]];
+    m_vecEdgeVector[static_cast<size_t>(m_mapEdgeId2Index[static_cast<int64>(end_edge_id)])];
     edge_t end_edge;
 
     if (end_part == 0.0) {
@@ -442,27 +292,37 @@ int GraphDefinition::my_dijkstra(edge_t *edges, size_t edge_count,
         }
     }
 
-    return(my_dijkstra(edges, edge_count, start_vertex, end_vertex, directed,
-        has_reverse_cost, path, path_count, err_msg, ruleList));
+    return(my_dijkstra2(
+                edges, edge_count,
+                start_vertex, end_vertex,
+                directed, has_reverse_cost,
+
+                path, path_count, err_msg,
+
+                ruleList));
 }
 
 
 // -------------------------------------------------------------------------
-int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
-    long start_vertex, long end_vertex, bool directed, bool has_reverse_cost,
-    path_element_tt **path, size_t *path_count, char **err_msg,
+int GraphDefinition:: my_dijkstra2(
+        edge_t *edges, size_t edge_count,
+    int64 start_vertex, int64 end_vertex,
+    bool directed, bool has_reverse_cost,
+
+    path_element_tt **path, size_t *path_count,
+    char **err_msg,
     std::vector<PDVI> &ruleList) {
     m_ruleTable.clear();
     LongVector vecsource;
     for (const auto &rule : ruleList) {
         size_t j;
         size_t seq_cnt = rule.second.size();
-        std::vector<long> temp_precedencelist;
+        std::vector<int64> temp_precedencelist;
         temp_precedencelist.clear();
         for (j = 1; j < seq_cnt; j++) {
             temp_precedencelist.push_back(rule.second[j]);
         }
-        long dest_edge_id = rule.second[0];
+        int64 dest_edge_id = rule.second[0];
         if (m_ruleTable.find(dest_edge_id) != m_ruleTable.end()) {
             m_ruleTable[dest_edge_id].push_back(Rule(rule.first,
                 temp_precedencelist));
@@ -479,7 +339,7 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
                 for (const auto &source : vecsource) {
                     temp_precedencelist.clear();
                     temp_precedencelist.push_back(
-                        m_vecEdgeVector[source]->m_lEdgeID);
+                        m_vecEdgeVector[static_cast<size_t>(source)]->m_lEdgeID);
                     m_ruleTable[dest_edge_id].push_back(Rule(rule.first,
                         temp_precedencelist));
                 }
@@ -492,20 +352,25 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
             vecsource = m_mapNodeId2Edge[end_vertex];
             for (const auto &source : vecsource) {
                 m_ruleTable.insert(std::make_pair(
-                    m_vecEdgeVector[source]->m_lEdgeID, tmpRules));
+                    m_vecEdgeVector[static_cast<size_t>(source)]->m_lEdgeID, tmpRules));
             }
         }
     }
     m_bIsturnRestrictOn = true;
-    return(my_dijkstra(edges, edge_count, start_vertex, end_vertex, directed,
-        has_reverse_cost, path, path_count, err_msg));
+    return(my_dijkstra3(
+                edges, edge_count,
+                start_vertex, end_vertex,
+                directed, has_reverse_cost,
+                path, path_count, err_msg));
 }
 
-
 // -------------------------------------------------------------------------
-int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
-    long start_vertex, long end_vertex, bool directed, bool has_reverse_cost,
-    path_element_tt **path, size_t *path_count, char **err_msg) {
+int GraphDefinition:: my_dijkstra3(
+        edge_t *edges, size_t edge_count,
+    int64 start_vertex, int64 end_vertex,
+    bool directed, bool has_reverse_cost,
+    path_element_tt **path, size_t *path_count, char **err_msg
+    ) {
     if (!m_bIsGraphConstructed) {
         init();
         construct_graph(edges, edge_count, has_reverse_cost, directed);
@@ -524,13 +389,13 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
     }
 
     if (m_mapNodeId2Edge.find(start_vertex) == m_mapNodeId2Edge.end()) {
-        *err_msg = (char *)"Source Not Found";
+        *err_msg = const_cast<char *>("Source Not Found");
         deleteall();
         return -1;
     }
 
     if (m_mapNodeId2Edge.find(end_vertex) == m_mapNodeId2Edge.end()) {
-        *err_msg = (char *)"Destination Not Found";
+        *err_msg = const_cast<char *>("Destination Not Found");
         deleteall();
         return -1;
     }
@@ -539,7 +404,7 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
     GraphEdgeInfo* cur_edge = NULL;
 
     for (const auto &source : vecsource) {
-        cur_edge = m_vecEdgeVector[source];
+        cur_edge = m_vecEdgeVector[static_cast<size_t>(source)];
         if (cur_edge->m_lStartNode == start_vertex) {
             if (cur_edge->m_dCost >= 0.0) {
                 m_dCost[cur_edge->m_lEdgeIndex].endCost = cur_edge->m_dCost;
@@ -559,13 +424,13 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
             }
         }
     }
-    long cur_node = -1;
+    int64 cur_node = -1;
 
     while (!que.empty()) {
         PDP cur_pos = que.top();
         que.pop();
-        long cured_index = cur_pos.second.first;
-        cur_edge = m_vecEdgeVector[cured_index];
+        int64 cured_index = cur_pos.second.first;
+        cur_edge = m_vecEdgeVector[static_cast<size_t>(cured_index)];
 
         if (cur_pos.second.second) {  // explore edges connected to end node
             cur_node = cur_edge->m_lEndNode;
@@ -591,7 +456,7 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
                 return 0;
             }
         }
-        *err_msg = (char *)"Path Not Found";
+        *err_msg = const_cast<char *>("Path Not Found");
         deleteall();
         return -1;
     } else {
@@ -615,9 +480,9 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
             }
         }
 
-        *path = (path_element_tt *) malloc(sizeof(path_element_tt) *
-        (m_vecPath.size() + 1));
-        *path_count = static_cast<int>(m_vecPath.size());
+        *path = reinterpret_cast<path_element_tt *>(
+                malloc(sizeof(path_element_tt) * (m_vecPath.size() + 1)));
+        *path_count = m_vecPath.size();
 
         for (size_t i = 0; i < *path_count; i++) {
             (*path)[i].vertex_id = m_vecPath[i].vertex_id;
@@ -637,16 +502,16 @@ int GraphDefinition:: my_dijkstra(edge_t *edges, size_t edge_count,
     return 0;
 }
 
-
 // -------------------------------------------------------------------------
 bool GraphDefinition::get_single_cost(double total_cost, path_element_tt **path,
      size_t *path_count) {
     GraphEdgeInfo* start_edge_info =
-    m_vecEdgeVector[m_mapEdgeId2Index[m_lStartEdgeId]];
+    m_vecEdgeVector[static_cast<size_t>(m_mapEdgeId2Index[m_lStartEdgeId])];
     if (m_dEndPart >= m_dStartpart) {
         if (start_edge_info->m_dCost >= 0.0 && start_edge_info->m_dCost *
             (m_dEndPart - m_dStartpart) <= total_cost) {
-            *path = (path_element_tt *) malloc(sizeof(path_element_tt) * (1));
+            *path = reinterpret_cast<path_element_tt *>(malloc(
+                        sizeof(path_element_tt) * (1)));
             *path_count = 1;
             (*path)[0].vertex_id = -1;
             (*path)[0].edge_id = m_lStartEdgeId;
@@ -659,7 +524,8 @@ bool GraphDefinition::get_single_cost(double total_cost, path_element_tt **path,
         if (start_edge_info->m_dReverseCost >= 0.0 &&
             start_edge_info->m_dReverseCost * (m_dStartpart - m_dEndPart) <=
             total_cost) {
-            *path = (path_element_tt *) malloc(sizeof(path_element_tt) * (1));
+            *path = reinterpret_cast<path_element_tt *>(malloc(
+                        sizeof(path_element_tt) * (1)));
             *path_count = 1;
             (*path)[0].vertex_id = -1;
             (*path)[0].edge_id = m_lStartEdgeId;
@@ -726,7 +592,7 @@ bool GraphDefinition::connectEdge(GraphEdgeInfo& firstEdge,
 
 // -------------------------------------------------------------------------
 bool GraphDefinition::addEdge(edge_t edgeIn) {
-    // long lTest;
+    // int64 lTest;
     Long2LongMap::iterator itMap = m_mapEdgeId2Index.find(edgeIn.id);
     if (itMap != m_mapEdgeId2Index.end())
         return false;
@@ -737,7 +603,7 @@ bool GraphDefinition::addEdge(edge_t edgeIn) {
     newEdge->m_vecEndConnedtedEdge.clear();
     newEdge->m_vecRestrictedEdge.clear();
     newEdge->m_lEdgeID = edgeIn.id;
-    newEdge->m_lEdgeIndex = m_vecEdgeVector.size();
+    newEdge->m_lEdgeIndex = static_cast<int64>(m_vecEdgeVector.size());
     newEdge->m_lStartNode = edgeIn.source;
     newEdge->m_lEndNode = edgeIn.target;
     newEdge->m_dCost = edgeIn.cost;
@@ -760,11 +626,11 @@ bool GraphDefinition::addEdge(edge_t edgeIn) {
     if (itNodeMap != m_mapNodeId2Edge.end()) {
         // Connect current edge with existing edge with start node
         // connectEdge(
-        long lEdgeCount = itNodeMap->second.size();
-        long lEdgeIndex;
+        int64 lEdgeCount = static_cast<int64>(itNodeMap->second.size());
+        int64 lEdgeIndex;
         for (lEdgeIndex = 0; lEdgeIndex < lEdgeCount; lEdgeIndex++) {
-            long lEdge = itNodeMap->second.at(lEdgeIndex);
-            connectEdge(*newEdge, *m_vecEdgeVector[lEdge], true);
+            int64 lEdge = itNodeMap->second.at(static_cast<size_t>(lEdgeIndex));
+            connectEdge(*newEdge, *m_vecEdgeVector[static_cast<size_t>(lEdge)], true);
         }
     }
 
@@ -774,11 +640,11 @@ bool GraphDefinition::addEdge(edge_t edgeIn) {
     if (itNodeMap != m_mapNodeId2Edge.end()) {
         // Connect current edge with existing edge with end node
         // connectEdge(
-        long lEdgeCount = itNodeMap->second.size();
-        long lEdgeIndex;
+        int64 lEdgeCount = static_cast<int64>(itNodeMap->second.size());
+        int64 lEdgeIndex;
         for (lEdgeIndex = 0; lEdgeIndex < lEdgeCount; lEdgeIndex++) {
-            long lEdge = itNodeMap->second.at(lEdgeIndex);
-            connectEdge(*newEdge, *m_vecEdgeVector[lEdge], false);
+            int64 lEdge = itNodeMap->second.at(static_cast<size_t>(lEdgeIndex));
+            connectEdge(*newEdge, *m_vecEdgeVector[static_cast<size_t>(lEdge)], false);
         }
     }
 
